#
# spec file for package openfst
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname libfst26
Name:           openfst
Version:        1.8.4
Release:        1.2
Summary:        Weighted finite-state transducer library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            http://www.openfst.org/
#https://www.openfst.org/twiki/bin/view/FST/FstDownload tarballs & NEWS
Source:         http://www.openfst.org/twiki/pub/FST/FstDownload/%name-%version.tar.gz
Patch1:         i586-80bitfp.patch
%if 0%{?suse_version} && 0%{?suse_version} < 1600
BuildRequires:  gcc12-c++ >= 8.1.0
%else
BuildRequires:  gcc-c++ >= 8.1.0
%endif
BuildRequires:  libtool
BuildRequires:  pkgconfig(zlib)

%description
OpenFst is a library for constructing, combining, optimizing and
searching weighted finite-state transducers (FSTs).

%package -n %lname
Summary:        Development files for OpenFST
Group:          System/Libraries

%description -n %lname
OpenFST is a library for constructing, combining, optimizing and
searching weighted finite-state transducers (FSTs).

This package requires SSE on 32-bit x86 to function.

%package devel
Summary:        Development files for OpenFST
Group:          Development/Libraries/C and C++
Requires:       %lname = %version-%release

%description devel
OpenFST is a library for constructing, combining, optimizing and
searching weighted finite-state transducers (FSTs).

%prep
%autosetup -p1

%build
%if 0%{?suse_version} && 0%{?suse_version} < 1600
export CXX=g++-12
%endif
autoreconf -fi
%configure
%make_build

%install
%make_install
find %buildroot/%_libdir -type f -name "*.la" -print -delete

%ldconfig_scriptlets -n %lname

%files
%license COPYING
%_bindir/fst*

%files -n %lname
%_libdir/lib*fst*.so.*

%files devel
%_includedir/fst/
%_libdir/*.so

%changelog
* Sun Feb  9 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.4
  * Added `NumStatesIfKnown()` method to `FstClass` in script
    layer and `num_states_if_known()` to `Fst` in Python layer,
    exposing library-layer `Fst::NumStatesIfKnown()`
  * Added an option allowing `ArcMapFst` to be an `ExpandedFst`
    (thus only accepting `ExpandedFst` inputs) rather than
    always fulfilling just the `Fst` interface, even when it
    could have provided `NumStates()`
  * Modest performance optimizations in `SingleShortestPath`
  * Added `CustomShortestFirstQueue`, a generalization of
    `NaturalShortestFirstQueue` allowing setting a custom
    comparator
  * Removed nominal memory leak in `fstquantize` binary which
    would occur briefly before exiting
  * Various properties and flags in script API (as
    `WeightClass::Properties()`) and Python extension (as
    `WeightProperties`, `ArcIteratorFlags` and
    `EncodeMapperFlags`) are now exposed
- Delete gcc14.patch (obsolete)
* Sat Nov  2 2024 Jan Engelhardt <jengelh@inai.de>
- Add gcc14.patch
* Thu Feb  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.8.3
  * Eliminated negative label option in `SymbolTable`
  * Changed `allow_negative_labels` arg of `SymbolTable.read_text` to
    keyword-only in pywrapfst
  * Added `FastNumStates` method
  * Split `cc-visitors.h` from `connect.h`
  * Standardized default seeds for `fstrandgen`
* Mon Jul  5 2021 Jan Engelhardt <jengelh@inai.de>
- Initial package for build.opensuse.org (version 1.8.1)
- Add i586-80bitfp.patch
